"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const vscode_languageserver_types_1 = require("vscode-languageserver-types");
const js_beautify_1 = require("js-beautify");
const prettyhtml = require("@starptech/prettyhtml");
const templateHead = '<template>';
const templateTail = '</template>';
function htmlFormat(document, currRange, formattingOptions, config) {
    if (config.vetur.format.defaultFormatter.html === 'none') {
        return [];
    }
    const { value, range } = getValueAndRange(document, currRange);
    let beautifiedHtml;
    if (config.vetur.format.defaultFormatter.html === 'prettyhtml') {
        beautifiedHtml = formatWithPrettyHtml(templateHead + value + templateTail, formattingOptions, config);
    }
    else {
        beautifiedHtml = formatWithJsBeautify(templateHead + value + templateTail, formattingOptions, config);
    }
    const wrappedHtml = beautifiedHtml.substring(templateHead.length, beautifiedHtml.length - templateTail.length);
    return [
        {
            range,
            newText: wrappedHtml
        }
    ];
}
exports.htmlFormat = htmlFormat;
function formatWithPrettyHtml(input, formattingOptions, config) {
    const result = prettyhtml(input, Object.assign({ useTabs: !formattingOptions.insertSpaces, tabWidth: formattingOptions.tabSize, usePrettier: true, prettier: Object.assign({}, config.prettier) }, config.vetur.format.defaultFormatterOptions['prettyhtml']));
    return result.contents.trim();
}
function formatWithJsBeautify(input, formattingOptions, config) {
    const htmlFormattingOptions = _.assign(defaultHtmlOptions, {
        indent_with_tabs: !formattingOptions.insertSpaces,
        indent_size: formattingOptions.tabSize
    }, config.vetur.format.defaultFormatterOptions['js-beautify-html'], { end_with_newline: false });
    return js_beautify_1.html(input, htmlFormattingOptions);
}
function getValueAndRange(document, currRange) {
    let value = document.getText();
    let range = currRange;
    if (currRange) {
        const startOffset = document.offsetAt(currRange.start);
        const endOffset = document.offsetAt(currRange.end);
        value = value.substring(startOffset, endOffset);
    }
    else {
        range = vscode_languageserver_types_1.Range.create(vscode_languageserver_types_1.Position.create(0, 0), document.positionAt(value.length));
    }
    return { value, range };
}
const defaultHtmlOptions = {
    end_with_newline: false,
    indent_char: ' ',
    indent_handlebars: false,
    indent_inner_html: false,
    indent_scripts: 'keep',
    indent_size: 2,
    indent_with_tabs: false,
    max_preserve_newlines: 1,
    preserve_newlines: true,
    unformatted: [],
    wrap_line_length: 0,
    wrap_attributes: 'auto'
    // Wrap attributes to new lines [auto|force|force-aligned|force-expand-multiline] ["auto"]
};
//# sourceMappingURL=htmlFormat.js.map