/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const htmlParser_1 = require("../parser/htmlParser");
const htmlHover_1 = require("../services/htmlHover");
const hover_test_util_1 = require("../../test-util/hover-test-util");
const tagProviders_1 = require("../tagProviders");
const html = hover_test_util_1.hoverDSL({
    docUri: 'test://test/test.html',
    langId: 'vue-html',
    doHover(document, position) {
        const htmlAST = htmlParser_1.parseHTMLDocument(document);
        return htmlHover_1.doHover(document, position, htmlAST, tagProviders_1.allTagProviders);
    }
});
suite('HTML Hover', () => {
    test('Single', function () {
        html `|<html></html>`.hasNothing();
        html `<|html></html>`.hasHoverAt('<html>', 1);
        html `<h|tml></html>`.hasHoverAt('<html>', 1);
        html `<htm|l></html>`.hasHoverAt('<html>', 1);
        html `<html|></html>`.hasHoverAt('<html>', 1);
        html `<div|></div>`.hasHoverAt('<div>', 1);
        html `<html>|</html>`.hasNothing();
        html `<html><|/html>`.hasNothing();
        html `<html></|html>`.hasHoverAt('</html>', 8);
        html `<html></h|tml>`.hasHoverAt('</html>', 8);
        html `<html></ht|ml>`.hasHoverAt('</html>', 8);
        html `<html></htm|l>`.hasHoverAt('</html>', 8);
        html `<html></html|>`.hasHoverAt('</html>', 8);
        html `<|component></component>`.hasHoverAt('<component>', 1);
        html `<html></html>|`.hasNothing();
        html `<div>{{tes|t}}</div>`.hasNothing();
    });
    test('Attribute', function () {
        html `<div a|ria-atomic="true"></div>`.hasHoverAt('No doc for aria-atomic', 5);
        html `<component inli|ne-template></component>`.hasHoverAt('treat inner content as its template rather than distributed content', 11);
        html `<div :v|-if="true"></div>`.hasHoverAt('Conditionally renders the element based on the truthy\\-ness of the expression value\\.', 5);
    });
});
//# sourceMappingURL=hover.test.js.map